from setuptools import setup
setup(name='pyBS_QS', 
version='0.15', 
description='this package has been prepared a binarysearch allgorithm using quicksort',
packages=['BS.BS','QS.QuickSort'],
zip_safe=False)